Zusatz — rtdpy 0.6.0 documentation

# Zusatz

class `rtdpy.zusatz.` `Zusatz`(b, c, dt, time_end)

  Bases: `rtdpy.rtd.RTD`

  Create Zusatz Residence Time Distribution (RTD) model. [1] Parameter a is chosen such that the integral is 1.

  \[\begin{split}E(t) = a t^{-c-1} b^{c+1} \text{exp}\left[\left(b^c t^{-c} -1\right)\frac{-c-1}{c}\right] \\a = \frac{1+c}{b\, \text{exp}\left[1+1/c\right]}\end{split}\]
  Parameters
    bscalar

      b Zusatz parameter. `b>0`

    cscalar

      c Zusatz parameter. `c>0` Mean residence time only defined for `c>1`. Variance only defined for `c>2`.

    dtscalar

      Time step for RTD. `dt>0`

    time_endscalar

      End time for RTD. `time_end>0`

  References

  1

    Poulesquen A., et al. (2003) A study of residence time distribution in co-rotating twin-screw extruders. Part II: Experimental validation. “Polymer Engineering and Science”, 43(12), 1849-1862.

  Examples

      >>> import matplotlib.pyplot as plt
      >>> import rtdpy
      >>> for c in [3, 7]:
      >>>     a = rtdpy.Zusatz(b=25, c=c, dt=.01, time_end=100)
      >>>     plt.plot(a.time, a.exitage, label=f"c={c}")
      >>> plt.xlabel('Time')
      >>> plt.ylabel('Exit Age Function')
      >>> plt.legend()
      >>> plt.show()

  property `a`

    a parameter that normalizes RTD to 1

  property `b`

    b parameter

  property `c`

    c parameter

  property `dt`

    Time step for RTD

  property `exitage`

    Exit age distribution for RTD

  property `exitage_norm`

    Normalized Exit Age Distribtion for RTD

  `frequencyresponse`(omegas)
    Parameters
      omegasndarray

        frequencies at which to evaluate magnitude response

    Returns
      magnitudendarray

        frequency magnitude response at omegas

  `funnelplot`(times, disturbances)

    Return maximum output signal due to square disturbances.

    Uses method from [Garcia] . Also returns meshgrid for times and disturbance inputs for ease of plotting.

    Parameters
      timesarray_like, size m

        Times to determine funnelplot

      disturbancesarray_like, size n

        Disturbance magnitudes

    Returns
      x2D meshgrid size (mxn)

        times

      y2D meshgrid size (mxn)

        disturbances

      response2D meshgrid size (mxn)

        maximum response at (x,y)

    References

    Garcia

      Garcia-Munoz S., Butterbaugh A., Leavesley I., Manley L.F., Slade D., Bermingham S. (2018) A flowhseet model for the development of a continuous process for pharmaceutical tablets: An industrial perspective. “AIChE Journal”, 64(2), 511-525.

  `integral`()

    Integral of RTD.

  `mrt`()

    Mean residence time of RTD.

  `output`(inputtime, inputsignal)

    Convolves input signal with RTD

    Parameters
      inputtimendarray

        Times of input signal, which must have same dt as RTD. Size m

      inputsignalndarray

        Input signal. Size n

    Returns
      outputsignalndarrary

        Output signal at same dt. Size m + n -1

  `sigma`()

    Variance of RTD.

  property `stepresponse`

    Step respose of RTD

  property `stepresponse_norm`

    Normalized step respose of RTD

  property `time`

    Time points for exitage function.

  property `time_end`

    Last time point for RTD